package com.huertian.jinduguanli.controller;

import com.alibaba.excel.EasyExcel;
import com.huertian.jinduguanli.common.ApiResponse;
import com.huertian.jinduguanli.common.ErrorCode;
import com.huertian.jinduguanli.dto.DepartmentImportDTO;
import com.huertian.jinduguanli.dto.LessonTaskImportDTO;
import com.huertian.jinduguanli.dto.UserImportDTO;
import com.huertian.jinduguanli.service.DepartmentService;
import com.huertian.jinduguanli.service.LessonTaskService;
import com.huertian.jinduguanli.service.UserService;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

import java.util.List;

@Slf4j
@RestController
@RequestMapping("/api/import")
public class ImportController {

    @Autowired
    private UserService userService;

    @Autowired
    private LessonTaskService lessonTaskService;

    @Autowired
    private DepartmentService departmentService;

    @PostMapping("/users")
    public ApiResponse<String> importUsers(@RequestParam("file") MultipartFile file) {
        if (file.isEmpty()) {
            return new ApiResponse<>(ErrorCode.INVALID_PARAM, "文件不能为空", null);
        }

        String originalFilename = file.getOriginalFilename();
        if (!isValidExcelFile(originalFilename)) {
            return new ApiResponse<>(ErrorCode.INVALID_PARAM, "只支持.xlsx格式的文件", null);
        }

        try {
            log.info("开始导入用户数据，文件名：{}", originalFilename);
            List<UserImportDTO> userList = EasyExcel.read(file.getInputStream())
                    .head(UserImportDTO.class)
                    .sheet()
                    .doReadSync();
            log.info("读取到{}条用户数据", userList.size());

            for (int i = 0; i < userList.size(); i++) {
                log.info("第{}行数据：{}", i + 1, userList.get(i));
            }

            return userService.batchImportUsers(userList);
        } catch (Exception e) {
            log.error("导入用户数据失败", e);
            return new ApiResponse<>(ErrorCode.SYSTEM_ERROR, "导入用户数据失败：" + e.getMessage(), null);
        }
    }

    @PostMapping("/lesson-tasks")
    public ApiResponse<String> importLessonTasks(@RequestParam("file") MultipartFile file) {
        if (file.isEmpty()) {
            return new ApiResponse<>(ErrorCode.INVALID_PARAM, "文件不能为空", null);
        }

        String originalFilename = file.getOriginalFilename();
        if (!isValidExcelFile(originalFilename)) {
            return new ApiResponse<>(ErrorCode.INVALID_PARAM, "只支持.xlsx格式的文件", null);
        }

        try {
            log.info("开始导入课程任务数据，文件名：{}", originalFilename);
            List<LessonTaskImportDTO> taskList = EasyExcel.read(file.getInputStream())
                    .head(LessonTaskImportDTO.class)
                    .sheet()
                    .doReadSync();
            log.info("读取到{}条课程任务数据", taskList.size());

            for (int i = 0; i < taskList.size(); i++) {
                log.info("第{}行数据：{}", i + 1, taskList.get(i));
            }

            return lessonTaskService.batchImportLessonTasks(taskList);
        } catch (Exception e) {
            log.error("导入课程任务数据失败", e);
            return new ApiResponse<>(ErrorCode.SYSTEM_ERROR, "导入课程任务数据失败：" + e.getMessage(), null);
        }
    }

    @PostMapping("/departments")
    public ApiResponse<String> importDepartments(@RequestParam("file") MultipartFile file) {
        if (file.isEmpty()) {
            return new ApiResponse<>(ErrorCode.INVALID_PARAM, "文件不能为空", null);
        }

        String originalFilename = file.getOriginalFilename();
        if (!isValidExcelFile(originalFilename)) {
            return new ApiResponse<>(ErrorCode.INVALID_PARAM, "只支持.xlsx格式的文件", null);
        }

        try {
            log.info("开始导入部门数据，文件名：{}", originalFilename);
            List<DepartmentImportDTO> departmentList = EasyExcel.read(file.getInputStream())
                    .head(DepartmentImportDTO.class)
                    .sheet()
                    .doReadSync();
            log.info("读取到{}条部门数据", departmentList.size());

            for (int i = 0; i < departmentList.size(); i++) {
                log.info("第{}行数据：{}", i + 1, departmentList.get(i));
            }

            return departmentService.batchImportDepartments(departmentList);
        } catch (Exception e) {
            log.error("导入部门数据失败", e);
            return new ApiResponse<>(ErrorCode.SYSTEM_ERROR, "导入部门数据失败：" + e.getMessage(), null);
        }
    }

    private boolean isValidExcelFile(String filename) {
        return StringUtils.isNotBlank(filename) && filename.toLowerCase().endsWith(".xlsx");
    }
}
