package com.huertian.jinduguanli.service;

import com.huertian.jinduguanli.common.ApiResponse;
import com.huertian.jinduguanli.common.ErrorCode;
import com.huertian.jinduguanli.dto.DepartmentImportDTO;
import com.huertian.jinduguanli.entity.Department;
import com.huertian.jinduguanli.repository.DepartmentRepository;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

@Service
public class DepartmentService {
    private static final Logger logger = LoggerFactory.getLogger(DepartmentService.class);
    private final DepartmentRepository departmentRepository;

    @Autowired
    public DepartmentService(DepartmentRepository departmentRepository) {
        this.departmentRepository = departmentRepository;
    }

    public ApiResponse<String> batchImportDepartments(List<DepartmentImportDTO> departmentList) {
        if (departmentList == null || departmentList.isEmpty()) {
            return new ApiResponse<>(ErrorCode.PARAM_ERROR, "导入数据不能为空", null);
        }

        StringBuilder errorMsg = new StringBuilder();
        int successCount = 0;

        for (int i = 0; i < departmentList.size(); i++) {
            DepartmentImportDTO dto = departmentList.get(i);
            try {
                // 基本数据验证
                if (StringUtils.isBlank(dto.getDepartmentName())) {
                    errorMsg.append(String.format("第%d行部门名称不能为空;", i + 2));
                    continue;
                }

                // 检查部门名称是否已存在
                if (departmentRepository.findByName(dto.getDepartmentName()) != null) {
                    errorMsg.append(String.format("第%d行部门名称已存在;", i + 2));
                    continue;
                }

                // 创建部门
                Department department = new Department();
                department.setName(dto.getDepartmentName());
                department.setDescription(dto.getDescription());
                department.setCreatedAt(System.currentTimeMillis() / 1000);
                department.setUpdatedAt(System.currentTimeMillis() / 1000);

                departmentRepository.save(department);
                successCount++;
            } catch (Exception e) {
                logger.error("导入第{}行数据失败", i + 2, e);
                errorMsg.append(String.format("第%d行导入失败;", i + 2));
            }
        }

        String resultMsg = String.format("成功导入%d条数据", successCount);
        if (errorMsg.length() > 0) {
            resultMsg += "。错误信息：" + errorMsg;
        }

        // 如果没有成功导入任何数据，返回错误状态
        if (successCount == 0) {
            return new ApiResponse<>(ErrorCode.PARAM_ERROR, resultMsg, null);
        }

        return ApiResponse.success(resultMsg);
    }
}
